@@ -1,6 +1,6 @@
 package Web::PerlDistSite::Component::LayoutScss;
 
-our $VERSION = '0.001005';
+our $VERSION = '0.001006';
 
 use Moo;
 use Web::PerlDistSite::Common -lexical, -all;
@@ -111,6 +111,10 @@ header {
 	width: 100%;
 	font-size: 2rem;
 	
+	opacity: 1;
+	pointer-events: auto;
+	transition: opacity 0.6s ease-in-out;
+	
 	a:link, a:visited {
 		@extend .text-white;
 		text-decoration: underline;
@@ -124,6 +128,11 @@ header {
 	}
 }
 
+body.is-scrolled .homepage-hero-button {
+	opacity: 0;
+	pointer-events: none;
+}
+
 @keyframes bounce {
 	to { transform: scale(1.2); }
 }
